@@ -105,6 +105,10 @@ getRaster <- function(dataset_id = NULL,
     shp <- terra::vect(shp)
   }
   
+  if (!is.null(file_path) && !dir.exists(file_path)) {
+    stop(stringr::str_glue("Path to download rasters '{file_path}' must be an existing directory."))
+  }
+  
   message("Checking if the following Surface-Year combinations are available to download:")
   message(paste0("\n    ", "DATASET ID  ", "YEAR "))
   query_def <- data.frame()
@@ -215,7 +219,8 @@ getRaster <- function(dataset_id = NULL,
   } else if (length(rasters) == 1) {
     raster <- rasters[[1]]
     terra::NAflag(raster) <- -9999
-    names(raster) <- query_def$raster_title
+    
+    names(raster[[1]]) <- query_def$raster_title # Apply only to first/main band
     if (!is.null(shp)) {
       raster <- terra::mask(raster, shp)
     }
@@ -233,30 +238,9 @@ getRaster <- function(dataset_id = NULL,
         )))
       ))
     
-    #check whether more than one resolution is present in downloaded rasters
-    #if only one resolution is present, create a raster stack of all downloaded rasters
-    if (length(unique(rasters_index$res_id)) == 1) {
-      rst_stk <- terra::rast(rasters)
-      
-      terra::NAflag(rst_stk) <- -9999
-      
-      if (!is.null(shp)) {
-        rst_stk <- terra::mask(rst_stk, shp)
-      }
-      
-      names(rst_stk) <- query_def$raster_title
-      return(rst_stk)
-      #if not then we want to return a list of raster stacks - one for each resolution present in the index dataframe above.
-    } else if (length(unique(rasters_index$res_id)) != 1) {
-      #for each unique raster resolution create a raster stack and store this in stk_list
-      
-      stack_rst <- function(res_id) {
-        return(terra::rast(rasters[rasters_index$res_id == res_id]))
-      }
-      
-      stk_list <-
-        lapply(X = unique(rasters_index$res_id), FUN = stack_rst)
+      stk_list <- rasters
       
+      # Set NDV for all rasters
       for (i in 1:length(stk_list)) {
         for (r in 1:length(names(stk_list[[i]]))) {
           terra::NAflag(stk_list[[i]][[r]]) <- -9999
@@ -270,25 +254,36 @@ getRaster <- function(dataset_id = NULL,
                            mask = shp)
       }
       
-      # tidy names of rasters within the stacks within this list.
+      # Tidy names of main band of each raster
       for (i in 1:length(stk_list)) {
-        for (ii in 1:length(stk_list[i])) {
-          names(stk_list[i][[ii]]) <-
-            query_def$raster_title[query_def$file_name %in% names(stk_list[i][[ii]])]
-        }
+        names(stk_list[[i]][[1]]) <- query_def$raster_title[query_def$file_name %in% names(stk_list[i][[1]])]
       }
       return(terra::sprc(stk_list))
-    }
   }
 }
 
-#Define a small function that downloads rasters from the MAP geoserver to a specifed location
-download_rst <-
-  function(dataset_id,
-           extent,
-           year,
-           file_name, 
-           file_path) {
+#' Download rasters from the MAP geoserver to a specifed location. If file already exists it will read it instead.
+#' 
+#' @param dataset_id ID for dataset on MAP geoserver
+#' @param extent desired raster extent
+#' @param year desired year to download
+#' @param file_name file name (excluding extension) to save raster to
+#' @param file_path path to save raster to
+#' @return SpatRaster
+#' 
+download_rst <- function(
+    dataset_id,
+    extent,
+    year,
+    file_name, 
+    file_path
+) {
+    if(!is.null(file_path)) {
+      rst_path <- file.path(file_path, paste0(file_name, ".tiff"))
+      if (file.exists(rst_path)) {
+        return(terra::rast(rst_path))
+      }
+    }
     
     wcs_client <- get_wcs_client_from_raster_id(dataset_id)
     
@@ -320,7 +315,23 @@ download_rst <-
       terra::writeRaster(spat_raster, rst_path,  filetype = "GTiff", overwrite=FALSE)
     }
     
-    names(spat_raster) <- file_name
+    if (terra::nlyr(spat_raster) > 1) {
+      band_descriptions <- wcs_client$describeCoverage(dataset_id)$rangeType$field
+      
+      if (length(band_descriptions) < 1) {
+        stop(paste0("Multiple bands, but missing higher band descriptions. raster: ", names(spat_raster[[1]])))
+      } else {
+        band2_description <- band_descriptions[[2]]$description$value
+        if (!startsWith(band2_description, "Mask:")) {
+          message(paste0("Skipping second band '", band2_description, "'. Unknown how to handle it."))
+          spat_raster <- spat_raster[[1]]
+        } else {
+          names(spat_raster[[2]]) <- band2_description
+        }
+      }
+    }
+    
+    names(spat_raster[[1]]) <- file_name
     
     return(spat_raster)
   }
